==> vue-contentful-1.1.6.tgz: package/src/index.js <==
import 'core-js/es6/array'
import format from 'string-template'
import extend from 'lodash/extend'
import assign from 'lodash/assign'
import { createClient } from 'contentful/dist/contentful.legacy.min.js'

let data
let client
let settings
const locale = navigator.languages ? navigator.languages[0] : (navigator.language || navigator.userLanguage)

const localeWithoutSuffix = locale => locale.split('-')[0]

const getEntries = (contentTypeId, lockedLocale, includeLimit = 1, additionalQueries) => client.getEntries({
  locale: lockedLocale || localeWithoutSuffix(locale),
  content_type: contentTypeId,
  include: includeLimit,
  ...additionalQueries
})

const getFieldsWithIncludes = (contentTypeId, lockedLocale, includeLimit) => new Promise((resolve, reject) => {
  getEntries(contentTypeId, lockedLocale)
  .then(({includes, items}) => {
    const includesFields = includes.Entry.map(({fields}) => fields)
    data = assign(...includesFields)
  })
  .then(() => {
    resolve(data)
  })
})

const getFields = (contentTypeId, lockedLocale, includeLimit) => new Promise((resolve, reject) => {
  getEntries(contentTypeId, lockedLocale, includeLimit).then(({items}) => items.forEach(({fields}) => {
    data = fields
  })).then(() => {
    resolve(data)
  })
})

const getContentType = (contentTypeId, lockedLocale, includeLimit, additionalQueries) => new Promise((resolve, reject) => {
  let cache = []
  getEntries(contentTypeId, lockedLocale, includeLimit, additionalQueries).then(({ items }) => items.forEach(({ sys, fields }) => {
    cache.push({
      _id: sys.id,
      ...fields
    })
  })).then(() => {
    data = cache
    resolve(data)
  })
})

const getEntry = (entryId, lockedLocale, includeLimit, additionalQueries) => new Promise((resolve, reject) => {
  client
    .getEntry(entryId)
    .then(entry => {
      resolve(entry)
    })
    .catch(err => {
      reject(err)
    })
})

const VueContentful = {
  install (Vue, options) {
    settings = extend({
      space_id: null,
      access_token: null,
      content_type_id: null,
      lockLocaleTo: null,
      includeLimit: 1
    }, options)

    Vue.prototype.$t = null

    client = createClient({
      space: settings.space_id,
      accessToken: settings.access_token
    })

    Vue.prototype.$getLangFields = contentTypeId => getFields(contentTypeId, settings.lockLocaleTo, settings.includeLimit)
    Vue.prototype.$trans = (data, ...args) => format(data, ...args)
    Vue.prototype.$transChoice = (str, i, sep = ',') => str.split(sep)[i]
    Vue.prototype.$getContentType = (contentTypeId, additionalQueries, includeLimit) => getContentType(contentTypeId, settings.lockLocaleTo, includeLimit || settings.includeLimit, additionalQueries)
    Vue.prototype.$getEntry = ({ entryId, includes, query }) => getEntry(entryId, settings.lockLocaleTo, includes || settings.includeLimit, query)
  },
  init (Vue) {
    return new Promise((resolve, reject) => {
      getFieldsWithIncludes(settings.content_type_id, settings.lockLocaleTo, settings.includeLimit).then(() => {
        Vue.prototype.$t = data
        resolve(data)
      })
    })
  }
}

export default VueContentful

==> vue-contentful-1.1.9.tgz: package/src/index.js <==
import format from 'string-template'
import { createClient } from 'contentful/dist/contentful.legacy.min.js'

// Utilities
const extend = (target, sources) => {
  const _sources = [].concat(sources)
  const length = _sources.length;
  
   if (length < 1 || target == null) return target;
   for (let i = 0; i < length; i++) {
     const source = _sources[i];
 
     for (const key in source) {
       target[key] = source[key];
     }
   }
   return target;
 };

let data
let client
let settings
const locale = navigator.languages ? navigator.languages[0] : (navigator.language || navigator.userLanguage)

const localeWithoutSuffix = locale => locale.split('-')[0]

const getEntries = (contentTypeId, lockedLocale, includeLimit = 1, additionalQueries) => {
  const options = Object.assign({
    locale: lockedLocale || localeWithoutSuffix(locale),
    content_type: contentTypeId,
    include: includeLimit
  }, additionalQueries)

  return client.getEntries(options)
}

const getFieldsWithIncludes = (contentTypeId, lockedLocale, includeLimit) => new Promise((resolve, reject) => {
  getEntries(contentTypeId, lockedLocale)
  .then(({includes, items}) => {
    const includesFields = includes.Entry.map(({fields}) => fields)
    data = includesFields.reduce((obj, item) => Object.assign(obj, item), {})
  })
  .then(() => {
    resolve(data)
  })
})

const getFields = (contentTypeId, lockedLocale, includeLimit) => new Promise((resolve, reject) => {
  getEntries(contentTypeId, lockedLocale, includeLimit).then(({items}) => items.forEach(({fields}) => {
    data = fields
  })).then(() => {
    resolve(data)
  })
})

const getContentType = (contentTypeId, lockedLocale, includeLimit, additionalQueries) => new Promise((resolve, reject) => {
  let cache = []
  getEntries(contentTypeId, lockedLocale, includeLimit, additionalQueries).then(({ items }) => items.forEach(({ sys, fields }) => {
    const item = Object.assign({ _id: sys.id }, fields)
    cache.push(item)
  })).then(() => {
    data = cache
    resolve(data)
  })
})

const getEntry = (entryId, lockedLocale, includeLimit, additionalQueries) => new Promise((resolve, reject) => {
  client
    .getEntry(entryId)
    .then(entry => {
      resolve(entry)
    })
    .catch(err => {
      reject(err)
    })
})

const VueContentful = {
  install (Vue, options) {
    settings = extend({
      space_id: null,
      access_token: null,
      content_type_id: null,
      lockLocaleTo: null,
      includeLimit: 1
    }, options)

    Vue.prototype.$t = null

    client = createClient({
      space: settings.space_id,
      accessToken: settings.access_token
    })

    Vue.prototype.$getLangFields = contentTypeId => getFields(contentTypeId, settings.lockLocaleTo, settings.includeLimit)
    Vue.prototype.$trans = (data, args) => format(data, args)
    Vue.prototype.$transChoice = (str, i, sep = ',') => str.split(sep)[i]
    
    Vue.prototype.$getContentType = (contentTypeId, additionalQueries, includeLimit) => getContentType(contentTypeId, settings.lockLocaleTo, includeLimit || settings.includeLimit, additionalQueries)

    Vue.prototype.$getEntry = ({ entryId, includes, query }) => getEntry(entryId, settings.lockLocaleTo, includes || settings.includeLimit, query)

    Vue.prototype.$transMapMediaPaths = content => Object.keys(content).map(key => {
      const fields = content[key].fields
      return { [key]: fields ? fields.file.url : content[key] }
    }).reduce((obj, item) => {
      const key = Object.keys(item)
      obj[key] = item[key]
      return obj
    }, {})
  },
  init (Vue) {
    return new Promise((resolve, reject) => {
      getFieldsWithIncludes(settings.content_type_id, settings.lockLocaleTo, settings.includeLimit).then(() => {
        Vue.prototype.$t = data
        resolve(data)
      })
    })
  }
}

export default VueContentful
